@@ -10,8 +10,8 @@
 #include "stringutil.h"
 
 #include <QDateTime>
+#include <QList>
 #include <QVariant>
-#include <QVector>
 
 namespace KItinerary {
 
@@ -78,7 +78,7 @@ public:
     QVariantList processActions(QVariantList actions) const;
     template <typename T> QDateTime processTimeForLocation(QDateTime dt, const T &place) const;
 
-    QVector<QVariant> m_data;
+    QList<QVariant> m_data;
     QDateTime m_contextDate;
     bool m_resultFinalized = false;
 };
